@@ -3,8 +3,8 @@ import os
 
 import pygame, itertools
 
-from objects import *
-from TileMap import TileMap
+from bluebeam.objects import *
+from bluebeam.TileMap import TileMap
 
 
 class Level:
