@@ -1,7 +1,7 @@
 import math
 import os
 
-from objects import GameObject
+from bluebeam.objects import GameObject
 import pygame
 
 class BossSpawnTrigger(GameObject):
