@@ -1,4 +1,4 @@
-from objects import PhysObject
+from bluebeam.objects import PhysObject
 import pygame
 
 
