@@ -1,6 +1,6 @@
 import pygame
 import os
-from objects import Bullet
+from bluebeam.objects import Bullet
 
 
 
