@@ -2,7 +2,7 @@ import itertools
 
 import pygame
 import math
-from objects import EnemyBullet
+from bluebeam.objects import EnemyBullet
 
 
 class Laser(EnemyBullet):
