@@ -1,5 +1,5 @@
 import pygame
-from objects import Bullet
+from bluebeam.objects import Bullet
 import os
 
 
