@@ -1,4 +1,4 @@
-from objects import EnemyBullet, Explosion
+from bluebeam.objects import EnemyBullet, Explosion
 import pygame
 
 
