@@ -1,4 +1,4 @@
-from objects import WhaleTurret
+from bluebeam.objects import WhaleTurret
 import pygame
 import math
 
